function y=sigma0(data,mom_func,m,debugmode)
% PURPOSE: Estimate asymptotic variance of mthat (sigma0) via bootstrap with 1000
% bootstrap replications(see Oh, 692)
% INPUTS
%   data: TxN matrix of standard uniform data
%   mom_func: optional, string containing the name of the moment function,
%             default= 'momfunc_Equidep'
%   m: optional, number of moments (=size of output of mom_func), default=
%      5
%
% OUT = 5*5 bootstrap avar matrix using momfunc_Equidep

if nargin <4 || isempty(debugmode)
    debugmode=0;
end
if nargin<3
    m=5;
end
if nargin<2;
    mom_func='momfunc_Equidep';
end

[T,N]=size(data);
%disp('Estimating asymptotic covariance of the moment vector.')
B = T*1000;  % number of bootstrap samples, use 1000
b=1000;
if debugmode
    B=T*10;
    b=10;
end

myrand = randi([1 T],[B 1]); % randi = random uniform integers from a range

EtaB = zeros(B,N); % bootstrap samples
for ii=1:B
    EtaB(ii,:)= data(myrand(ii,1),:);
end

mtb= zeros(m,b); % moments of bootstrap samples
for jj=0:(b-1)
    mtb(:,jj+1)=feval(mom_func,(EtaB((1+T*jj):(T+T*jj),:)));
end
mtb=mtb';
y=T*cov(mtb);

